@@ -6,16 +6,17 @@ import time
 import sqlparse
 
 import dbt.project
+import dbt.utils
+
 from dbt.source import Source
 from dbt.utils import find_model_by_fqn, find_model_by_name, \
-    dependency_projects, split_path, This, Var, compiler_error, \
-    to_string
+     split_path, This, Var, compiler_error, to_string
 
 from dbt.linker import Linker
 from dbt.runtime import RuntimeContext
-import dbt.targets
 import dbt.templates
 
+from dbt.adapters.factory import get_adapter
 from dbt.logger import GLOBAL_LOGGER as logger
 
 CompilableEntities = [
@@ -43,7 +44,6 @@ class Compiler(object):
         self.project.args = args
 
         self.macro_generator = None
-        self.target = self.get_target()
 
     def initialize(self):
         if not os.path.exists(self.project['target-path']):
@@ -52,10 +52,6 @@ class Compiler(object):
         if not os.path.exists(self.project['modules-path']):
             os.makedirs(self.project['modules-path'])
 
-    def get_target(self):
-        target_cfg = self.project.run_environment()
-        return dbt.targets.get_target(target_cfg)
-
     def model_sources(self, this_project, own_project=None):
         if own_project is None:
             own_project = this_project
@@ -67,12 +63,6 @@ class Compiler(object):
                 own_project=own_project
             ).get_models(paths, self.create_template)
 
-        elif self.create_template.label == 'test':
-            return Source(
-                this_project,
-                own_project=own_project
-            ).get_test_models(paths, self.create_template)
-
         elif self.create_template.label == 'archive':
             return []
         else:
@@ -234,7 +224,7 @@ class Compiler(object):
 
         return wrapped_do_ref
 
-    def get_context(self, linker, model,  models, add_dependency=False):
+    def get_context(self, linker, model, models, add_dependency=False):
         runtime = RuntimeContext(model=model)
 
         context = self.project.context()
@@ -254,8 +244,8 @@ class Compiler(object):
         context['run_started_at'] = '{{ run_started_at }}'
         context['invocation_id'] = '{{ invocation_id }}'
 
-        # add in context from run target
-        context.update(self.target.context)
+        adapter = get_adapter(self.project.run_environment())
+        context['sql_now'] = adapter.date_function
 
         runtime.update_global(context)
 
@@ -277,10 +267,10 @@ class Compiler(object):
             fs_loader = jinja2.FileSystemLoader(searchpath=model.root_dir)
             jinja = jinja2.Environment(loader=fs_loader)
 
-            # this is a dumb jinja2 bug -- on windows, forward slashes
-            # are EXPECTED
-            posix_filepath = '/'.join(split_path(model.rel_filepath))
-            template = jinja.get_template(posix_filepath)
+            template_contents = dbt.clients.system.load_file_contents(
+                model.absolute_path)
+
+            template = jinja.from_string(template_contents)
             context = self.get_context(
                 linker, model, models, add_dependency=add_dependency
             )
@@ -526,7 +516,7 @@ class Compiler(object):
 
     def get_models(self):
         all_models = self.model_sources(this_project=self.project)
-        for project in dependency_projects(self.project):
+        for project in dbt.utils.dependency_projects(self.project):
             all_models.extend(
                 self.model_sources(
                     this_project=self.project, own_project=project
@@ -541,7 +531,7 @@ class Compiler(object):
         all_models = self.get_models()
         all_macros = self.get_macros(this_project=self.project)
 
-        for project in dependency_projects(self.project):
+        for project in dbt.utils.dependency_projects(self.project):
             all_macros.extend(
                 self.get_macros(this_project=self.project, own_project=project)
             )
