@@ -1,6 +1,7 @@
 import hashlib
 import jinja2
 from dbt.utils import compiler_error, to_unicode
+from dbt.adapters.factory import get_adapter
 
 
 class CompiledModel(object):
@@ -12,7 +13,7 @@ class CompiledModel(object):
         # these are set just before the models are executed
         self.tmp_drop_type = None
         self.final_drop_type = None
-        self.target = None
+        self.profile = None
 
         self.skip = False
         self._contents = None
@@ -76,12 +77,12 @@ class CompiledModel(object):
 
     @property
     def schema(self):
-        if self.target is None:
+        if self.profile is None:
             raise RuntimeError(
-                "`target` not set in compiled model {}".format(self)
+                "`profile` not set in compiled model {}".format(self)
             )
         else:
-            return self.target.schema
+            return get_adapter(self.profile).get_default_schema(self.profile)
 
     def should_execute(self, args, existing):
         if args.non_destructive and \
@@ -98,7 +99,7 @@ class CompiledModel(object):
         else:
             return self.materialization in ['table', 'view']
 
-    def prepare(self, existing, target):
+    def prepare(self, existing, profile):
         if self.materialization == 'incremental':
             tmp_drop_type = None
             final_drop_type = None
@@ -108,7 +109,7 @@ class CompiledModel(object):
 
         self.tmp_drop_type = tmp_drop_type
         self.final_drop_type = final_drop_type
-        self.target = target
+        self.profile = profile
 
     def __repr__(self):
         return "<CompiledModel {}.{}: {}>".format(
@@ -126,8 +127,8 @@ class CompiledTest(CompiledModel):
     def should_execute(self, args, existing):
         return True
 
-    def prepare(self, existing, target):
-        self.target = target
+    def prepare(self, existing, profile):
+        self.profile = profile
 
     def __repr__(self):
         return "<CompiledModel {}.{}: {}>".format(
@@ -145,8 +146,8 @@ class CompiledArchive(CompiledModel):
     def should_execute(self, args, existing):
         return True
 
-    def prepare(self, existing, target):
-        self.target = target
+    def prepare(self, existing, profile):
+        self.profile = profile
 
     def __repr__(self):
         return "<CompiledArchive {}.{}: {}>".format(
@@ -157,7 +158,7 @@ class CompiledArchive(CompiledModel):
 def make_compiled_model(fqn, data):
     run_type = data['dbt_run_type']
 
-    if run_type in ['run', 'dry-run']:
+    if run_type == 'run':
         return CompiledModel(fqn, data)
     elif run_type == 'test':
         return CompiledTest(fqn, data)
