@@ -7,6 +7,7 @@ import sys
 import re
 
 import dbt.version
+import dbt.flags as flags
 import dbt.project as project
 import dbt.task.run as run_task
 import dbt.task.compile as compile_task
@@ -19,6 +20,7 @@ import dbt.task.test as test_task
 import dbt.task.archive as archive_task
 import dbt.tracking
 import dbt.config as config
+import dbt.adapters.cache as adapter_cache
 
 
 def main(args=None):
@@ -41,6 +43,8 @@ def handle(args):
     # correct profiles.yml file
     if not config.send_anonymous_usage_stats(parsed.profiles_dir):
         dbt.tracking.do_not_track()
+    else:
+        dbt.tracking.initialize_tracking()
 
     res = run_from_args(parsed)
     dbt.tracking.flush()
@@ -90,24 +94,36 @@ def run_from_args(parsed):
         log_path = proj.get('log-path', 'logs')
 
     initialize_logger(parsed.debug, log_path)
+    logger.debug("Tracking: {}".format(dbt.tracking.active_user.state()))
 
     dbt.tracking.track_invocation_start(project=proj, args=parsed)
+
+    result = None
     try:
-        return task.run()
+        result = task.run()
         dbt.tracking.track_invocation_end(
             project=proj, args=parsed, result_type="ok", result=None
         )
+    except dbt.exceptions.NotImplementedException as e:
+        logger.info('ERROR: {}'.format(e))
+        dbt.tracking.track_invocation_end(
+            project=proj, args=parsed, result_type="error", result=str(e)
+        )
     except Exception as e:
         dbt.tracking.track_invocation_end(
             project=proj, args=parsed, result_type="error", result=str(e)
         )
         raise
 
+    return result
+
 
 def invoke_dbt(parsed):
     task = None
     proj = None
 
+    adapter_cache.reset()
+
     try:
         proj = project.read_project(
             'dbt_project.yml',
@@ -167,15 +183,14 @@ def invoke_dbt(parsed):
 def parse_args(args):
     p = argparse.ArgumentParser(
         prog='dbt: data build tool',
-        formatter_class=argparse.RawTextHelpFormatter
-    )
+        formatter_class=argparse.RawTextHelpFormatter)
 
     p.add_argument(
         '--version',
         action='version',
         version=dbt.version.get_version_information(),
-        help="Show version information"
-    )
+        help="Show version information")
+
     p.add_argument(
         '-d',
         '--debug',
@@ -183,6 +198,13 @@ def parse_args(args):
         help='''Display debug logging during dbt execution. Useful for
         debugging and making bug reports.''')
 
+    p.add_argument(
+        '-S',
+        '--strict',
+        action='store_true',
+        help='''Run schema validations at runtime. This will surface
+        bugs in dbt, but may incur a performance penalty.''')
+
     subs = p.add_subparsers()
 
     base_subparser = argparse.ArgumentParser(add_help=False)
@@ -220,11 +242,6 @@ def parse_args(args):
     sub.set_defaults(cls=clean_task.CleanTask, which='clean')
 
     sub = subs.add_parser('compile', parents=[base_subparser])
-    sub.add_argument(
-        '--dry',
-        action='store_true',
-        help="Compile 'dry run' models"
-    )
     sub.add_argument(
         '--non-destructive',
         action='store_true',
@@ -262,7 +279,6 @@ def parse_args(args):
     sub.set_defaults(cls=archive_task.ArchiveTask, which='archive')
 
     sub = subs.add_parser('run', parents=[base_subparser])
-    sub.add_argument('--dry', action='store_true', help="'dry run' models")
     sub.add_argument(
         '--models',
         required=False,
