@@ -1,13 +1,13 @@
-
 import os.path
 import yaml
 import jinja2
 import re
-from dbt.templates import BaseCreateTemplate, DryCreateTemplate
+from dbt.templates import BaseCreateTemplate
 from dbt.utils import split_path
 import dbt.schema_tester
 import dbt.project
 import dbt.archival
+from dbt.adapters.factory import get_adapter
 from dbt.utils import deep_merge, DBTConfigKeys, compiler_error, \
     compiler_warning
 
@@ -202,6 +202,10 @@ class DBTSource(object):
 
         self.source_config = SourceConfig(project, own_project, self.fqn)
 
+    @property
+    def absolute_path(self):
+        return os.path.join(self.root_dir, self.rel_filepath)
+
     @property
     def root_dir(self):
         return os.path.join(self.own_project['project-root'], self.top_dir)
@@ -230,9 +234,7 @@ class DBTSource(object):
 
     @property
     def contents(self):
-        filepath = os.path.join(self.root_dir, self.rel_filepath)
-        with open(filepath) as fh:
-            return fh.read().strip()
+        return dbt.clients.system.load_file_contents(self.absolute_path)
 
     @property
     def config(self):
@@ -351,27 +353,8 @@ class Model(DBTSource):
 
         sort_type = sort_type.strip().lower()
 
-        valid_sort_types = ['compound', 'interleaved']
-        if sort_type not in valid_sort_types:
-            compiler_error(
-                self,
-                "Invalid sort_type given: {} -- must be one of {}".format(
-                    sort_type, valid_sort_types
-                )
-            )
-
-        if type(sort_keys) == str:
-            sort_keys = [sort_keys]
-
-        # remove existing quotes in field name, then wrap in quotes
-        formatted_sort_keys = [
-            '"{}"'.format(sort_key.replace('"', '')) for sort_key in sort_keys
-        ]
-        keys_csv = ', '.join(formatted_sort_keys)
-
-        return "{sort_type} sortkey ({keys_csv})".format(
-            sort_type=sort_type, keys_csv=keys_csv
-        )
+        adapter = get_adapter(self.project.run_environment())
+        return adapter.sort_qualifier(sort_type, sort_keys)
 
     def dist_qualifier(self, model_config):
         if 'dist' not in model_config:
@@ -390,10 +373,8 @@ class Model(DBTSource):
 
         dist_key = dist_key.strip().lower()
 
-        if dist_key in ['all', 'even']:
-            return 'diststyle {}'.format(dist_key)
-        else:
-            return 'diststyle key distkey ("{}")'.format(dist_key)
+        adapter = get_adapter(self.project.run_environment())
+        return adapter.dist_qualifier(dist_key)
 
     def build_path(self):
         build_dir = self.create_template.label
@@ -521,48 +502,6 @@ class Analysis(Model):
         return "<Analysis {}: {}>".format(self.name, self.filepath)
 
 
-class TestModel(Model):
-    dbt_run_type = 'dry-run'
-
-    def __init__(
-            self,
-            project,
-            target_dir,
-            rel_filepath,
-            own_project,
-            create_template
-    ):
-        return super(TestModel, self).__init__(
-            project, target_dir, rel_filepath, own_project, create_template
-        )
-
-    def build_path(self):
-        build_dir = self.create_template.label
-        filename = "{}.sql".format(self.name)
-        path_parts = [build_dir] + self.fqn[:-1] + [filename]
-        return os.path.join(*path_parts)
-
-    @property
-    def fqn(self):
-        """fully-qualified name for model. Includes all subdirs below 'models'
-        path and the filename"""
-        parts = split_path(self.filepath)
-        name, _ = os.path.splitext(parts[-1])
-        test_name = DryCreateTemplate.model_name(name)
-        return [self.own_project['name']] + parts[1:-1] + [test_name]
-
-    @property
-    def original_fqn(self):
-        parts = split_path(self.filepath)
-        name, _ = os.path.splitext(parts[-1])
-        return [self.project['name']] + parts[1:-1] + [name]
-
-    def __repr__(self):
-        return "<TestModel {}.{}: {}>".format(
-            self.project['name'], self.name, self.filepath
-        )
-
-
 class SchemaTest(DBTSource):
     test_type = "base"
     dbt_run_type = 'test'
