@@ -1,5 +1,5 @@
 from dbt.compilation import Compiler, CompilableEntities
-from dbt.templates import BaseCreateTemplate, DryCreateTemplate
+from dbt.templates import BaseCreateTemplate
 from dbt.logger import GLOBAL_LOGGER as logger
 
 
@@ -9,12 +9,7 @@ class CompileTask:
         self.project = project
 
     def run(self):
-        if self.args.dry:
-            create_template = DryCreateTemplate
-        else:
-            create_template = BaseCreateTemplate
-
-        compiler = Compiler(self.project, create_template, self.args)
+        compiler = Compiler(self.project, BaseCreateTemplate, self.args)
         compiler.initialize()
         results = compiler.compile(limit_to=CompilableEntities)
 
