@@ -1,11 +1,9 @@
 from __future__ import print_function
 
-import os
-
 from dbt.compilation import Compiler, CompilableEntities
 from dbt.logger import GLOBAL_LOGGER as logger
 from dbt.runner import RunManager
-from dbt.templates import DryCreateTemplate, BaseCreateTemplate
+from dbt.templates import BaseCreateTemplate
 
 THREAD_LIMIT = 9
 
@@ -16,9 +14,7 @@ class RunTask:
         self.project = project
 
     def compile(self):
-        create_template = DryCreateTemplate if self.args.dry \
-                          else BaseCreateTemplate
-        compiler = Compiler(self.project, create_template, self.args)
+        compiler = Compiler(self.project, BaseCreateTemplate, self.args)
         compiler.initialize()
         results = compiler.compile(limit_to=['models'])
 
@@ -27,7 +23,7 @@ class RunTask:
         ])
         logger.info("Compiled {}".format(stat_line))
 
-        return create_template.label
+        return BaseCreateTemplate.label
 
     def run(self):
         graph_type = self.compile()
@@ -36,10 +32,7 @@ class RunTask:
             self.project, self.project['target-path'], graph_type, self.args
         )
 
-        if self.args.dry:
-            results = runner.dry_run(self.args.models)
-        else:
-            results = runner.run(self.args.models)
+        results = runner.run(self.args.models)
 
         total = len(results)
         passed = len([r for r in results if not r.errored and not r.skipped])
